////////////////////////////////////////////////////////////////////////////////////////////
//Project: Cross Implementation - Provided By Synactive, Inc.
//Developed By: Synactive, Inc.
//File Version: 1.0
//File Purpose: Defines System functions that can be leveraged across implementations
////////////////////////////////////////////////////////////////////////////////////////////

// Creation Date: 8/13/2018
// Change Log:	Version   Date   Dev  Peer   Change Note
//              1.0       08/13  JRL  TUB    original
//              2.0		  01/16	 JRL  AJD	 Added Sprint 2 Functionality


//This functions replaces characters in a string with a single given character
function StringCharReplace(start,end,temp,repl){
	var repl_str = "";
	var temp_str_front = "";
	var temp_str_back = "";

	for (i=start; i<end; i++){
		repl_str = repl_str+repl;
	}

	temp_str_front = temp.substring(0,start);
	temp_str_back = temp.substring(end,temp.length);

	return(temp_str_front + repl_str + temp_str_back);
}


// This function checks for if there is all underscores in the string
// and if there is, it will return a blank string, else return the original string
function checkForUnderscore(str){
	
	abc = str.replace(/^\_+|\_+$/g, "");
	if(abc.length == 0){
		return abc;
	}
	else{
		return str;
	}

}


// This function is used to print statements in the Cornelius output
// with a padding of equal signs, to clearly stand out
function bugprint(str){

	println("==========================================================================");
	println("====>"+str+"<====");
	println("==========================================================================");

}


function return_window(){
	return;
}


function donothing(){
	return;
}


////////////////////////////////////////////////////////////////////////////////////////////
//Check if Screen Control exists str = "F[Material]", str = '#[3,0]'
////////////////////////////////////////////////////////////////////////////////////////////
function isControl(str) {
	return Reebok(str).isValid;
}

////////////////////////////////////////////////////////////////////////////////////////////
//Function prototypes, to remove blank spaces from variable values
////////////////////////////////////////////////////////////////////////////////////////////
String.prototype.trim = function() {
	return this.replace(/^\s+|\s+$/g,"");
}

////////////////////////////////////////////////////////////////////////////////////////////
//Checks whether a variable contains a value or not
////////////////////////////////////////////////////////////////////////////////////////////
// This function is used to check if a variable is "blank"
function isBlank(jvar){
	if(typeof jvar == undefined || jvar == null || jvar == "" || jvar == void 0)
		return true;
	else
		return jvar.toString().trim() == '';
}

// Check if variable has value, opposite of isBlank that we have been using
function hasValue(jvar){
	if(isBlank(jvar)) return false;
	else return true;
}

// Pass indexed variable as string
function hasEvalValue(strIndexedVariable) {
	set('V[z_variable]','&V['+strIndexedVariable+']');
	if(hasValue(z_variable)) return true;
	else return false;            
}

////////////////////////////////////////////////////////////////////////////////////////////
//Function prototypes, to remove commas from variable values
////////////////////////////////////////////////////////////////////////////////////////////
String.prototype.removeComma = function() {
	return this.replace(/,/g,'');	
}


///////////////////////////////////////////////////////////////////////////////////////////
// Pad zeros:
// number = Number to pad (string or integer)
// digits = Number of digits to pad
// Example: pad(78,5) will result in 00078
///////////////////////////////////////////////////////////////////////////////////////////

function padZeroes(number,digits) {
	if (typeof(number) != string)
		number = number.toString();

	for (var i=0; i<digits; i++){
		if (number.length < digits){
			number = '0' + number;
		}
	}   
	return (number);   
}


////////////////////////////////////////////////////////////////////////////////////////////
//Function to pad a string with characters
////////////////////////////////////////////////////////////////////////////////////////////
const PADDING_LEFT = 0;
const PADDING_RIGHT = 1;
function padString(source,length,direction,character) {
	var loop;
	var output = "";
	var sourceLength = 0;
	set('V[z_source]',source);
	if(z_source) {
		sourceLength = z_source.length;
	}
	
	switch(direction) {
	case PADDING_LEFT:
		for(loop = 0; loop < (length - sourceLength); loop++) {
			output += character;
		}
		output = output + z_source;
		break;
		
	case PADDING_RIGHT:
		for(loop = 0; loop < (length - sourceLength); loop++) {
			output += character;
		}
		output = z_source + output;
		break;
	}
	return output;
}

////////////////////////////////////////////////////////////////////////////////////////////
//Format Date (flag, months, 'next'/'prev', keyDate)
// dformat = supports formats 1 - 6.
//		1 --> DD.MM.YYYY
//		2 --> MM/DD/YYYY
//		3 --> MM-DD-YYYY
//		4 --> YYYY.MM.DD
//		5 --> YYYY/MM/DD
//		6 --> YYYY-MM-DD 
// months = Number of months before or after today (if 0, it will return todays date)
// monthsOpert = 'next' or 'prev' 
// keyDate = date to calculate from (array with format: ["yyyy","m","d"])
//  example: getFormattedDate("1", 3, "prev", ["2010","5","11"]); --> 3 months prior to May 11th, 2010 
// NOTE: if using 'prev', maximum number of months is 12
////////////////////////////////////////////////////////////////////////////////////////////
function getFormattedDate(dformat, months, monthsOpert, keyDate) {
	var z_date = new Date();
	if (keyDate != null && keyDate.length > 0){
		z_date.setDate(keyDate[2]);
		z_date.setMonth(keyDate[1]-1);
		z_date.setYear(keyDate[0]);
	}
	if (monthsOpert == 'next') {
					z_date.setMonth(z_date.getMonth()+months);
	} else if (monthsOpert == 'prev') {
					z_date.setMonth(z_date.getMonth()-months);
	}
	
	var str = "";
	switch(dformat) 
	{
		case '1':
		{
				str = pad(z_date.getDate(),2) + "." + pad((z_date.getMonth()+1),2) + "." + z_date.getFullYear();
		}
		break;
		 
		case '2':
		{
		   str = pad((z_date.getMonth()+1),2) + "/" + pad(z_date.getDate(),2) + "/" + z_date.getFullYear();
		}
		break;

		case '3':
		{
		   str = pad((z_date.getMonth()+1),2) + "-" + pad(z_date.getDate(),2) + "-" + z_date.getFullYear();
		}
		break;
	
		case '4':
		{
		   str = z_date.getFullYear() + "." + pad((z_date.getMonth()+1),2) + "." + pad(z_date.getDate(),2);
		}
		break;

		case '5':
		{
		   str = z_date.getFullYear() + "/" + pad((z_date.getMonth()+1),2) + "/" + pad(z_date.getDate(),2);
		}
		break;
		
		case '6':
		{
		   str = z_date.getFullYear() + "-" + pad((z_date.getMonth()+1),2) + "-" + pad(z_date.getDate(),2);
		}
		break;
	}
  return str;
}

/***********************************************************
* Function to change the date format from input to output 
* format
***********************************************************/
function changeFormat(date,dformat,outformat){
	arDateValues = check_date_format(date,dformat);
	if (arDateValues.length == 0){
		return ("Invalid Format");
	}
	day = arDateValues[0];
	month = arDateValues[1];
	year = arDateValues[2];
	date1 = "";
	switch (outformat){
			case '1':
				date1 = day + "." + month + "." + year;
				break;
			case '2':
				date1 = month + "/" + day + "/" + year;			
				break;
			case '3':
				date1 = month + "-" + day + "-" + year;							
				break;
			case '4':
				date1 = year + "." + month + "." + day;			
				break;
			case '5':
				date1 = year + "/" + month + "/" + day;				
				break;
			case '6':
				date1 = year + "-" + month + "-" + day;
				break;
			case '7':
				date1 = year + month + day;
				break;				
		}
		return (date1);	
}


/***********************************************************
* Function to check date for a valid date format
***********************************************************/
function check_date_format(date,dformat){
	arValues = [];
	arTmpValues = [];
	switch (parseInt(dformat)){
		case 1:
			var matches = /^([0]?[1-9]|[12][0-9]|3[01])\.([0]?[1-9]|1[012])\.[0-9]{4}/.exec(date);
			//var matches = /^(\d{2})[-\.](\d{2})[-\.](\d{4})$/.exec(date);
			if (matches == null) return ([]);
			else {
				arTmpValues = date.toString().split(".");
				return (arTmpValues);
			}
			break;
		case 2:
			var matches = /^([0]?[1-9]|1[012])\/([0]?[1-9]|[12][0-9]|3[01])\/[0-9]{4}/.exec(date);
			//var matches = /^(\d{1,2})(-\/)(\d{1,2})(-\/)(\d{2,4})$/.exec(date);
			if (matches == null) return ([]);
			else {				
				arTmpValues = date.toString().split("/");
				return ([arTmpValues[1],arTmpValues[0],arTmpValues[2]]);
			}
			break;
		case 3:
			//var matches = /^(\d{2})-(\d{2})-(\d{4})$/.exec(date);
			var matches = /^([0]?[1-9]|1[012])\-([0]?[1-9]|[12][0-9]|3[01])\-[0-9]{4}/.exec(date);
			if (matches == null) return ([]);
			else {
				arTmpValues = date.toString().split("-");
				return ([arTmpValues[1],arTmpValues[0],arTmpValues[2]]);
			}
			break;	
		case 4:
			//var matches = /^(\d{4})[-\.](\d{2})[-\.](\d{2})$/.exec(date);
			var matches = /^[0-9]{4}\.([0]?[1-9]|1[012])\.([0]?[1-9]|[12][0-9]|3[01])/.exec(date);
			if (matches == null) return ([]);
			else {
				arTmpValues = date.toString().split(".");
				return ([arTmpValues[2],arTmpValues[1],arTmpValues[0]]);
			}
			break;
		case 5:
			//var matches = /^(\d{4})[-\/](\d{2})[-\/](\d{2})$/.exec(date);
			var matches = /^[0-9]{4}\/([0]?[1-9]|1[012])\/([0]?[1-9]|[12][0-9]|3[01])/.exec(date);
			if (matches == null) return ([]);
			else {
				arTmpValues = date.toString().split("/");
				return ([arTmpValues[2],arTmpValues[1],arTmpValues[0]]);
			}
			break;
		case 6:
			var matches = /^[0-9]{4}\-([0]?[1-9]|1[012])\-([0]?[1-9]|[12][0-9]|3[01])/.exec(date);
//			var matches = /^(\d{4})-(\d{2})-(\d{2})$/.exec(date);
			if (matches == null) return ([]);
			else {
				arTmpValues = date.toString().split("-");
				return ([arTmpValues[2],arTmpValues[1],arTmpValues[0]]);
			}
			break;
	}
}


function isValidDate(date,dformat){

                switch (parseInt(dformat)){
                case 1:
                                var matches = /^(\d{2})[-\.](\d{2})[-\.](\d{4})$/.exec(date);
                                if (matches == null) return false;
                                else return true;
                                break;
                case 2:		
                                var matches = /^(\d{2})[-\/](\d{2})[-\/](\d{4})$/.exec(date);
                                if (matches == null) return false;
                                else return true;
                                break;
                case 3:
                                var matches = /^(\d{2})-(\d{2})-(\d{4})$/.exec(date);
                                if (matches == null){ return false;}
                                else{  return true;}
                                break;   
                case 4:
                                var matches = /^(\d{4})[-\.](\d{2})[-\.](\d{2})$/.exec(date);
                                if (matches == null) return false;
                                else return true;
                                break;
                case 5:
                                var matches = /^(\d{4})[-\/](\d{2})[-\/](\d{2})$/.exec(date);
                                if (matches == null) return false;
                                else return true;
                                break;
                case 6:
                                var matches = /^(\d{4})-(\d{2})-(\d{2})$/.exec(date);
                                if (matches == null) return false;
                                else return true;
                                break;
                }                              

			}

			
function parseDateString(date,dformat){
	//grab the format from SAP
	// parse year day and month based on '/'
	date1 = "";
	day = date[0];
	month = date[1];
	month = month-1;
	year = date[2];
	
	entereddate =  new Date(year, month, day);
			if(entereddate == "Invalid Date"){
		} else {
			var firstday = new Date(entereddate.setDate(entereddate.getDate() - entereddate.getDay()));
		}
	
	sunday = firstday.getDate();
	sundaymonth = firstday.getMonth()+1;
	sundayyear = firstday.getFullYear();
	
	switch (dformat){
			case '1':
				date1 = sunday + "." + sundaymonth + "." + sundayyear;
				break;
			case '2':
				date1 = sundaymonth + "/" + sunday + "/" + sundayyear;			
				break;
			case '3':
				date1 = sundaymonth + "-" + sunday + "-" + sundayyear;							
				break;
			case '4':
				date1 = sundayyear + "." + sundaymonth + "." + sunday;			
				break;
			case '5':
				date1 = sundayyear + "/" + sundaymonth + "/" + sunday;				
				break;
			case '6':
				date1 = sundayyear + "-" + sundaymonth + "-" + sunday;
				break;
		}
	return(date1);
}


// Function changes date from YYYYMMDD format to SAP User Date Format
function getDateInUserFormat(strDate,dFormat){
	var userDateFormat = "";
	var year = strDate.substring(0,4);
	var month = strDate.substring(4,6);
	var date = strDate.substring(6,8);
	switch (dFormat){
		case '1':
			userDateFormat = date + "." + month + "." + year;
			break;
		case '2':
			userDateFormat = month + "/" + date + "/" + year;			
			break;
		case '3':
			userDateFormat = month + "-" + date + "-" + year;							
			break;
		case '4':
			userDateFormat = year + "." + month + "." + date;			
			break;
		case '5':
			userDateFormat = year + "/" + month + "/" + date;				
			break;
		case '6':
			userDateFormat = year + "-" + month + "-" + date;
			break;
	}
	return (userDateFormat);	
}


function getTodaysDate(dFormat) {
	offsetDays = 0;
	var someDate = new Date();
	var numberOfDaysToAdd = offsetDays;
	someDate.setDate(someDate.getDate() + numberOfDaysToAdd); 
	var dd = someDate.getDate();
	dd = (dd <= 9) ? '0'+dd:dd;
	var mm = someDate.getMonth() + 1;
	mm = (mm <= 9) ? '0'+mm:mm;
	var y = someDate.getFullYear();	
	y = y+''+mm+''+dd;
	return(getDateInUserFormat(y,dFormat));
}


////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// Convert Date to SAP's Date Format
// Example: YYYYMMDD --> DD.MM.YYYY if user dformat is 1
//	valid SAP formats: 
	// 1. DD.MM.YYYY
	// 2. MM/DD/YYYY
	// 3. MM-DD-YYYY
	// 4. YYYY.MM.DD
	// 5. YYYY/MM/DD
	// 6. YYYY-MM-DD
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function SAPDateFormat(date,dformat){
	var date1 = "";
	year = date.substring(0,4);
	month = date.substring(4,6);
	date = date.substring(6,8);
	
	switch (parseInt(dformat)){
		case 1:
			date1 = date + "." + month + "." + year;
			break;
		case 2:	
			date1 = month + "/" + date + "/" + year;			
			break;
		case 3:
			date1 = month + "-" + date + "-" + year;							
			break;
		case 4:
			date1 = year + "." + month + "." + date;			
			break;
		case 5:
			date1 = year + "/" + month + "/" + date;				
			break;
		case 6:
			date1 = year + "-" + month + "-" + date;
			break;
	}

	return (date1);	
}


function getFutureDate(days,dformat){
		var curr_date = new Date();
		curr_date.setMilliseconds(curr_date.getMilliseconds()+(days*24*60*60*1000));
		
		var tmp_cur_month = curr_date.getMonth();
		var tmp_cur_date = curr_date.getDate();
		var tmp_cur_year = curr_date.getFullYear();
		
		if(tmp_cur_month<9)
			tmp_cur_month = "0"+(tmp_cur_month+1);
		else
			tmp_cur_month = (tmp_cur_month+1).toString();
		
		if(tmp_cur_date<10)
			tmp_cur_date = "0"+tmp_cur_date;
		
		var z_target_date = SAPDateFormat(tmp_cur_year+tmp_cur_month+tmp_cur_date,dformat);
		
		return z_target_date;
}

// Usage: 	arrNum = retrieveNumbersFromString('Order 2893292 saved and 983029320 retrived');
function retrieveNumbersFromString(strMessage) {
	var myarr = [];
    var res = strMessage.match(/[-+]?[0-9]*\.?[0-9]+/g);
    myarr = res.toString().split(',');
	return myarr;
}


function z_date(){		
	var d = new Date();
	var z_Year = d.getFullYear().toString().substring(0,4);
	var z_Month = d.getMonth();
	if(d.getMonth()<9){          
		z_Month =  "0" + (d.getMonth()+1)
	} else{                                
		z_Month = (d.getMonth()+1)
	}
	var z_Day = d.getDate();
	if(d.getDate()<9){               
		z_Day =  "0" + (d.getDate())
	} else{                               
		z_Day = (d.getDate())
	}
		
	return(z_Year+"/"+z_Month +"/"+ z_Day);	
}


////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// Get today's date in format YYYYMMDD
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function getTodaysDateYMD() {
	var date = new Date();
	var year = date.getFullYear();
	var month = (1 + date.getMonth()).toString();
	month = month.length > 1 ? month : '0' + month;
	var day = date.getDate().toString();
	day = day.length > 1 ? day : '0' + day;
	return year + month + day;
}


function z_getDateStr(){
	var d = new Date();
	var z_Year = d.getFullYear().toString().substring(3,4);
	var z_Month = d.getMonth();
	if(d.getMonth()<9){          
		z_Month =  "0" + (d.getMonth()+1)
	} else{                                
		z_Month = (d.getMonth()+1)
	}
	var z_Day = d.getDate();
	if(d.getDate()<9){               
		z_Day =  "0" + (d.getDate())
	} else{                               
		z_Day = (d.getDate())
	}
	var z_Hour = d.getHours();
	if(z_Hour == 0)
		z_Hour = "A";
	else if(z_Hour == 1)
		z_Hour = "B";
	else if(z_Hour == 2)
		z_Hour = "C";
	else if(z_Hour == 3)
		z_Hour = "D";
	else if(z_Hour == 4)
		z_Hour = "E";
	else if(z_Hour == 5)
		z_Hour = "F";
	else if(z_Hour == 6)
		z_Hour = "G";
	else if(z_Hour == 7)
		z_Hour = "H";
	else if(z_Hour == 8)
		z_Hour = "I";
	else if(z_Hour == 9)
		z_Hour = "J";
	else if(z_Hour == 10)
		z_Hour = "K";
	else if(z_Hour == 11)
		z_Hour = "L";
	else if(z_Hour == 12)
		z_Hour = "M";
	else if(z_Hour == 13)
		z_Hour = "N";
	else if(z_Hour == 14)
		z_Hour = "O";
	else if(z_Hour == 15)
		z_Hour = "P";
	else if(z_Hour == 16)
		z_Hour = "Q";
	else if(z_Hour == 17)
		z_Hour = "R";
	else if(z_Hour == 18)
		z_Hour = "S";
	else if(z_Hour == 19)
		z_Hour = "T";
	else if(z_Hour == 20)
		z_Hour = "U";
	else if(z_Hour == 21)
		z_Hour = "V";
	else if(z_Hour == 22)
		z_Hour = "W";
	else if(z_Hour == 23)
		z_Hour = "X";
	var z_Min = d.getMinutes();
	if(d.getMinutes()<9){              
		z_Min =  "0" + (d.getMinutes())
	} else{                              
		z_Min = (d.getMinutes())
	}
	var z_Sec = d.getSeconds();
	if(d.getSeconds()<9){              
		z_Sec =  "0" + (d.getSeconds())
	} else{                              
		z_Sec = (d.getSeconds())
	}
	return(z_Year+""+z_Month +""+ z_Day +""+ z_Hour+""+ z_Min +""+ z_Sec);	
		
}


Array.prototype.indexOfArr = function(searchElement, fromIndex) {
    "use strict";
    var k;

    // 1. Let o be the result of calling ToObject passing
    //    the this value as the argument.
    if (this == null) {
		throw new TypeError('"this" is null or not defined');
    }

    var o = Object(this);

    // 2. Let lenValue be the result of calling the Get
    //    internal method of o with the argument "length".
    // 3. Let len be ToUint32(lenValue).
    var len = o.length >>> 0;

    // 4. If len is 0, return -1.
    if (len === 0) {
		return -1;
    }

    // 5. If argument fromIndex was passed let n be
    //    ToInteger(fromIndex); else let n be 0.
    var n = fromIndex | 0;

    // 6. If n >= len, return -1.
    if (n >= len) {
		return -1;
    }

    // 7. If n >= 0, then Let k be n.
    // 8. Else, n<0, Let k be len - abs(n).
    //    If k is less than 0, then let k be 0.
    k = Math.max(n >= 0 ? n : len - Math.abs(n), 0);

    // 9. Repeat, while k < len
    for (; k < len; k++) {
		// a. Let Pk be ToString(k).
		//   This is implicit for LHS operands of the in operator
		// b. Let kPresent be the result of calling the
		//    HasProperty internal method of o with argument Pk.
		//   This step can be combined with c
		// c. If kPresent is true, then
		//    i.  Let elementK be the result of calling the Get
		//        internal method of o with the argument ToString(k).
		//   ii.  Let same be the result of applying the
		//        Strict Equality Comparison Algorithm to
		//        searchElement and elementK.
		//  iii.  If same is true, return k.
		if (k in o && o[k] === searchElement)
			return k;
    }
	return -1;
};


//Compares 2 arrays and returns unique items from first array
function compareArrsRetUnique(array1,array2){
	var index;
	for (var i=0; i<array2.length; i++) {
		index = array1.indexOfArr(array2[i]);
		if (index > -1) {
			array1.splice(index, 1);
		}
	}
	return array1;
}



//Function to find index of the key in an object
// z_ziw66_matlserialnum_arr = [];
// z_ziw66_matlserialnum_arr.push({key:"AAA",value:"111"});
// z_ziw66_matlserialnum_arr.push({key:"BBB",value:"222"});
// z_ziw66_matlserialnum_arr.push({key:"CCC",value:"333"});
// z_ziw66_matlserialnum_arr.push({key:"DDD",value:"444"});
// var idx = z_ziw66_matlserialnum_arr.indexOfObject("key", "DDD");
// println("\n====z_ziw66_matlserialnum_arr[idx].value:"+z_ziw66_matlserialnum_arr[idx].value+":");
Array.prototype.indexOfObject = function (property, value) {
    for (var i = 0, len = this.length; i < len; i++) {
        if (this[i][property] === value) return i;
    }
    return -1;
}


/***********************************************************
* Function to convert UTC date to string format
***********************************************************/
function convertUTCtoString(param){
	if (isBlank(param)){
		gDate = new Date();
	}
	else{
		gDate = param;
	}
	var z_day = gDate.getDate();
	if (z_day < 10) z_day = "0" + z_day;
	var z_month = gDate.getMonth() + 1;
	if (z_month < 10) z_month = "0" + z_month;
	var z_year = gDate.getFullYear();
	gDate = z_month + "/" + z_day + "/" + z_year;
	return gDate;
}


//Function to get calculated date from today according to input date and date difference 
function getCalculatedDate(strDate, strInputDateFormat, intDiff, strOutputDateFormat){
	if(!hasValue(strDate)){
		var dateObj = new Date();
	}
	else{
		var dateObj = new Date(changeFormat(strDate,strInputDateFormat.toString(),"5"));
	}
	
	if(!(!intDiff || parseInt(intDiff) == 0)){
		dateObj.setDate(dateObj.getDate() + parseInt(intDiff));
	}
	
	return changeFormat(convertUTCtoString(dateObj),"2",strOutputDateFormat.toString());
}



////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// Get Year based on Today's Date
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function getYear() {
	var date = new Date();
	var year = date.getFullYear();
	return year;
}


////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// Get current time in the format hh:mm:ss
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function getTimeHMS() {
	var curDate = new Date();
	var strHour = padString(curDate.getHours(),2,PADDING_LEFT,"0");
	var strMin = padString(curDate.getMinutes(),2,PADDING_LEFT,"0");
	var strSec = padString(curDate.getSeconds(),2,PADDING_LEFT,"0");
	var timeStr = strHour+":"+strMin+":"+strSec;
	return timeStr;
}


////////////////////////////////////////////////////////////////////////////////////////////
//Calculating the difference between two known dates
////////////////////////////////////////////////////////////////////////////////////////////
function daysBetween(date1, date2){
	//Get 1 day in milliseconds
	var one_day = 1000*60*60*24;

	var date1 = new Date(date1);
	var date2 = new Date(date2);
	
	//Convert both dates to milliseconds
	var date1_ms = date1.getTime();
	var date2_ms = date2.getTime();
	
	//Calculate the difference in milliseconds
	var difference_ms = date2_ms - date1_ms;

	//Convert back to days and return
	return Math.round(difference_ms/one_day);
	
	
}

// Function to get Description of a key value
// Usage: bbObject = {'FF':'Customer Block','ZZ':'Vendor Block'};
// Usage: bbDescription = getKeyDescription(bbObject,'FF');	// Will Return Customer Block
function getKeyDescription(inpObject,strKey){
	if(strKey in inpObject){
		return inpObject[strKey];
	}else{
		return '';
	}
}


//Function to navigate screen for UI (Back button as well)
function scrNavigation(param){
	set("V[Z_SCREEN]", param.l_mode);
	set("V[FROM_SCREEN]","");
	set("V[FROM_FULLSCREEN]","");
	set("V[Z_SUBSCR]","");
	if(param.z_mode == 'INIT'){
		set("V[z_mm03*]","");
		set("V[z_ie03*]","");
		set("V[z_iw31*]","");
		set("V[z_iw21*]","");
		set("V[z_iw41*]","");
		set("V[z_iw33*]","");
		set("V[z_copytext]","");
		copytext({"fromstring":"z_copytext","totext":"z_iw31_desctxtbox"});
		copytext({"fromstring":"z_copytext","totext":"z_iw21_desctxtbox"});
	}
}


function convertTextToArray(inpText) {
	var outArr = [];
	outArr = inpText.split('\n');
	return outArr;
}


//Function to check if longtext is blank
function isTextBoxBlank(longText) {
	var bTextExist = true;
	var arrText = longText.split('\n');
	for(i=0;i<arrText.length;i++) {
		if(!isBlank(arrText[i].trim())) {
			bTextExist = false;
			break;
		}
	}
	return bTextExist;
}


//Function to split a string into an array with specified char size	
function splitText(longText, charSize){
	charSize = parseInt(charSize);
	var textArray = longText.split('\n');
	var resultArray = [], matchedArray = [];
	var new_line_content = "", remained_line_content = "", cur_line = "";
	
	for(var i=0; i<textArray.length; i++){
		new_line_content = textArray[i].replace(/\t+/g," ").trim();		//Text editor doesn't support Tab content
		
		do{
			remained_line_content = "";
			if(new_line_content.length > charSize){
				cur_line = new_line_content.substring(0,charSize);
				matchedArray = cur_line.match(/((\S*\s+\S*)+\s)|(\S*)/g);
				remained_line_content = new_line_content.substring(matchedArray[0].length, new_line_content.length)
				new_line_content = matchedArray[0];
			}
			resultArray.push(new_line_content);
			new_line_content = remained_line_content;
		} while(new_line_content.length > 0)
	}
	               
	return resultArray;
}


// Function to clear the Liquid UI table based on parameters
function clear_values(tablename, columnArray, rows){   
	for (var loop = 0; loop < rows; loop++){
		for (var col=0; col<columnArray.length; col++){   
			tablename[columnArray[col]][loop] = "";
		}
	}   
}

